pub fn set_eval_callback(ctx: &EvalContext, f: EvalCallbackFn)Expand description
Register the full evaluator callback for host compatibility.
Stores it on both ctx and the shared host-only STDLIB_CTX.
pub fn set_eval_callback(ctx: &EvalContext, f: EvalCallbackFn)Register the full evaluator callback for host compatibility.
Stores it on both ctx and the shared host-only STDLIB_CTX.