pub struct Span {
pub line: usize,
pub col: usize,
pub end_line: usize,
pub end_col: usize,
}Fields
line: usizecol: usizeend_line: usizeend_col: usizeImplementations
Sourceimpl Span
impl Span
Sourcepub fn new(line: usize, col: usize, end_line: usize, end_col: usize) -> Self
pub fn new(line: usize, col: usize, end_line: usize, end_col: usize) -> Self
Create a span with explicit start and end.
Sourcepub fn to(self, other: &Span) -> Span
pub fn to(self, other: &Span) -> Span
Create a span from the start of self to the end of other.
Sourcepub fn with_end(self, end_line: usize, end_col: usize) -> Span
pub fn with_end(self, end_line: usize, end_col: usize) -> Span
Create a span from the start of self to an explicit end position.
Sourcepub fn contains(&self, other: &Span) -> bool
pub fn contains(&self, other: &Span) -> bool
Check if self fully contains other (inclusive bounds).
Sourcepub fn contains_pos(&self, line: usize, col: usize) -> bool
pub fn contains_pos(&self, line: usize, col: usize) -> bool
Check if position (line, col) falls within this span (inclusive).