ValueViewRef

Enum ValueViewRef 

pub enum ValueViewRef<'a> {
Show 34 variants Nil, Bool(bool), Int(i64), BigInt(&'a BigInt), Rational(&'a BigRational), Complex(&'a Complex), Float(f64), String(&'a str), Symbol(Spur), Keyword(Spur), Char(char), List(&'a [Value]), Vector(&'a [Value]), Map(&'a BTreeMap<Value, Value>), HashMap(&'a HashMap<Value, Value>), Lambda(&'a Lambda), Macro(&'a Macro), NativeFn(&'a NativeFn), Prompt(&'a Prompt), Message(&'a Message), Conversation(&'a Conversation), ToolDef(&'a ToolDefinition), Agent(&'a Agent), Thunk(&'a Thunk), Record(&'a Record), Bytevector(&'a [u8]), MultiMethod(&'a MultiMethod), Stream(&'a StreamBox), F64Array(&'a [f64]), I64Array(&'a [i64]), AsyncPromise(&'a AsyncPromise), Channel(&'a Channel), MutableArray(&'a MutableArray), MutableCell(&'a MutableCell),
}
A borrowing view of a Value — like ValueView but returns references instead of cloning Rcs, avoiding refcount mutations on every comparison, hash, and ordering operation.

Variants



Nil



Bool(bool)



Int(i64)



BigInt(&'a BigInt)



Rational(&'a BigRational)



Complex(&'a Complex)



Float(f64)



String(&'a str)



Symbol(Spur)



Keyword(Spur)



Char(char)



List(&'a [Value])



Vector(&'a [Value])



Map(&'a BTreeMap<Value, Value>)



HashMap(&'a HashMap<Value, Value>)



Lambda(&'a Lambda)



Macro(&'a Macro)



NativeFn(&'a NativeFn)



Prompt(&'a Prompt)



Message(&'a Message)



Conversation(&'a Conversation)



ToolDef(&'a ToolDefinition)



Agent(&'a Agent)



Thunk(&'a Thunk)



Record(&'a Record)



Bytevector(&'a [u8])



MultiMethod(&'a MultiMethod)



Stream(&'a StreamBox)



F64Array(&'a [f64])



I64Array(&'a [i64])



AsyncPromise(&'a AsyncPromise)



Channel(&'a Channel)



MutableArray(&'a MutableArray)



MutableCell(&'a MutableCell)